/**
 * Fetches the data at the URL.
 * @param {*} url The URL of the API.
 * @param {*} callback The function to be recalled with the data.
 */
const callApi = (url, callback) => {
    fetch(url)
        .then(response => {
            if (response.ok) {
                return response.json();
            }

            throw new Error("Something went wrong, receive " + response.status + " status on " + response.url);
        })
        .then(data => {
            callback(data);
        })
        .catch(error => {
            console.log(error.message);
        });
};

callApi('/public-config', data => {
    const BASE_URL = "http://" + data.backend_ip_address + "/api/v1";

    callApi(BASE_URL + '/cv/summary', data => {
        document.title =
            "CV de  " + data.title + ' ' + data.firstname + ' ' + data.lastname;

        document.getElementById('header-photo').src = data.photo;
        document.getElementById('header-title').innerHTML =
            data.title + ' ' + data.firstname + ' ' + data.lastname;

        document.getElementById('personal-information-email').innerHTML = data.email;
        document.getElementById('personal-information-address').innerHTML = data.postalAddress;
        document.getElementById('personal-information-phone-number').innerHTML = data.phone;
        document.getElementById('personal-information-website').href = data.website;
    });

    callApi(BASE_URL + '/cv/contact', data => {
        document.getElementById('contact-information-message').innerHTML = data.message;
        document.getElementById('contact-information-phone-number').innerHTML = data.phone;
        document.getElementById('contact-information-email').innerHTML = data.email;
    });

    callApi(BASE_URL + '/cv/experiences', data => {
        let html = '';

        for (const [i, v] of data.entries()) {
            html += `
        <div class="experiences-item">
        <div class="company">${v.company}</div>
        <p>${v.location}</p>

        <p class="mt-2">
            <span class="title">${v.title}</span>
            <span class="duration">⸱ ${v.startDate} - ${v.endDate === null ? "" : v.endDate}</span>
        </p>

        <blockquote class="mt-2">
            <div></div>
            <p>
                ${v.description}
            </p>
        </blockquote>

        <h4>Tâches</h4>
        <div class="tasks-container">
        `;

            for (const task of v.tasks) {
                html += `
            <div class="tasks-item">
                <div class="name">${task.name}</div>
                <p>${task.description}</p>
            </div>
            `;
            }

            html += '</div></div>';

            if (i < data.length - 1) {
                html += '<hr>';
            }
        }

        document.getElementById("experiences").innerHTML = html;
    });

    callApi(BASE_URL + '/cv/educations', data => {
        let html = '';

        for (const [i, v] of data.entries()) {
            html += `
        <div class="experiences-item">
            <div class="company">${v.school}</div>
            <p>${v.title}</p>

            <p class="mt-2">
                <span class="title">${v.startDate} - ${v.endDate === null ? "" : v.endDate}</span>
                <span class="duration">⸱ ${v.location}</span>
            </p>

            <blockquote class="mt-2">
                <div></div>
                <p>
                    ${v.description}
                </p>
            </blockquote>
        </div>
        `;

            if (i < data.length - 1) {
                html += '<hr>';
            }
        }

        document.getElementById("education").innerHTML = html;
    });

    /**
     * Generates the HTML code for the skills section.
     * @param {*} skills The list of skills.
     * @returns The generated HTML code.
     */
    const generateSkillsHtml = skills => {
        let html = '';

        for (const skill of skills) {
            html += `
        <div class="tasks-item">
            <div class="name">${skill.title}</div>
            <p>${skill.level}</p>
        </div>
        `;
        }

        return html;
    };

    callApi(BASE_URL + '/cv/skills', data => {
        document.getElementById("skills").innerHTML =
            generateSkillsHtml(data.filter(x => x.type !== 'languages'));
        document.getElementById("languages").innerHTML =
            generateSkillsHtml(data.filter(x => x.type === 'languages'));
    });
});
